<?php
/**
 * TestDateSetting Plugin for LimeSurvey
 *
 */
class TestDateSetting extends PluginBase {

    static protected $name = 'TestDateSetting';
    static protected $description = 'Pluginto test HTML DB setting.';

    protected $storage = 'DbStorage';
    protected $settings = array(
        'checkDate1'=>array(
            'type'=>'date',
            'label' => 'A date, only year and month was saved',
            'default' => '',
            'saveformat' => "Y-m"
        ),
        'checkDate2'=>array(
            'type'=>'date',
            'label' => 'Another date',
            'default' => '',
        ),
        'checkDate3'=>array(
            'type'=>'date',
            'label' => 'A date saved as shown',
            'default' => '',
            'saveformat' => false
        ),
    );

    public function init() {
        $this->subscribe('beforeSurveySettings');
        $this->subscribe('newSurveySettings');
    }

    /**
     * Register the settings
     */
    public function beforeSurveySettings()
    {
        $oEvent = $this->event;
        $surveyId = $oEvent->get('survey');
        $oEvent->set(
            "surveysettings.{$this->id}",
            array(
                'name' => get_class($this),
                'settings' => array(
                    'checkDate1' => array(
                        'type' => 'date',
                        'label' => 'A date only saved',
                        'saveformat' =>"Y-m-d",
                        'current' => $this->get('checkDate1', 'Survey', $surveyId, ''),
                    ),
                    'checkDate2'=>array(
                        'type'=>'date',
                        'label' => 'Another date',
                        'current' => $this->get('checkDate2', 'Survey', $surveyId, ''),
                    ),
                    'checkDate3'=>array(
                        'type'=>'date',
                        'label' => 'A date saved as shown',
                        'default' => '',
                        'saveformat' => false,
                        'current' => $this->get('checkDate3', 'Survey', $surveyId, ''),
                    ),
                )
            )
        );
    }

    /** @inheritdoc **/
    public function newSurveySettings()
    {
        $event = $this->event;
        tracevar($event->get('settings'));
        foreach ($event->get('settings') as $name => $value) {
            $this->set($name, $value, 'Survey', $event->get('survey'));
        }
    }
}
